@@ -104,9 +104,7 @@ class IndicesClient(NamespacedClient):
             "POST", _make_path(index, "_flush"), params=params, headers=headers
         )
 
-    @query_params(
-        "include_type_name", "master_timeout", "timeout", "wait_for_active_shards"
-    )
+    @query_params("master_timeout", "timeout", "wait_for_active_shards")
     async def create(self, index, body=None, params=None, headers=None):
         """
         Creates an index with optional settings and mappings.
@@ -115,8 +113,6 @@ class IndicesClient(NamespacedClient):
         :arg index: The name of the index
         :arg body: The configuration for the index (`settings` and
             `mappings`)
-        :arg include_type_name: Whether a type should be expected in the
-            body of the mappings.
         :arg master_timeout: Specify timeout for connection to master
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
@@ -162,7 +158,6 @@ class IndicesClient(NamespacedClient):
         "flat_settings",
         "ignore_unavailable",
         "include_defaults",
-        "include_type_name",
         "local",
         "master_timeout",
     )
@@ -183,8 +178,6 @@ class IndicesClient(NamespacedClient):
             false)
         :arg include_defaults: Whether to return all default setting for
             each of the indices.
-        :arg include_type_name: Whether to add the type name to the
-            response (default: false)
         :arg local: Return local information, do not retrieve the state
             from master node (default: false)
         :arg master_timeout: Specify timeout for connection to master
@@ -332,50 +325,15 @@ class IndicesClient(NamespacedClient):
             "HEAD", _make_path(index), params=params, headers=headers
         )
 
-    @query_params("allow_no_indices", "expand_wildcards", "ignore_unavailable", "local")
-    async def exists_type(self, index, doc_type, params=None, headers=None):
-        """
-        Returns information about whether a particular document type exists.
-        (DEPRECATED)
-
-
-        :arg index: A comma-separated list of index names; use `_all` to
-            check the types across all indices
-        :arg doc_type: A comma-separated list of document types to check
-        :arg allow_no_indices: Whether to ignore if a wildcard indices
-            expression resolves into no concrete indices. (This includes `_all`
-            string or when no indices have been specified)
-        :arg expand_wildcards: Whether to expand wildcard expression to
-            concrete indices that are open, closed or both.  Valid choices: open,
-            closed, hidden, none, all  Default: open
-        :arg ignore_unavailable: Whether specified concrete indices
-            should be ignored when unavailable (missing or closed)
-        :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        """
-        for param in (index, doc_type):
-            if param in SKIP_IN_PATH:
-                raise ValueError("Empty value passed for a required argument.")
-
-        return await self.transport.perform_request(
-            "HEAD",
-            _make_path(index, "_mapping", doc_type),
-            params=params,
-            headers=headers,
-        )
-
     @query_params(
         "allow_no_indices",
         "expand_wildcards",
         "ignore_unavailable",
-        "include_type_name",
         "master_timeout",
         "timeout",
         "write_index_only",
     )
-    async def put_mapping(
-        self, body, index=None, doc_type=None, params=None, headers=None
-    ):
+    async def put_mapping(self, body, index=None, params=None, headers=None):
         """
         Updates the index mappings.
 
@@ -384,7 +342,6 @@ class IndicesClient(NamespacedClient):
         :arg index: A comma-separated list of index names the mapping
             should be added to (supports wildcards); use `_all` or omit to add the
             mapping on all indices.
-        :arg doc_type: The name of the document type
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -393,8 +350,6 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg include_type_name: Whether a type should be expected in the
-            body of the mappings.
         :arg master_timeout: Specify timeout for connection to master
         :arg timeout: Explicit operation timeout
         :arg write_index_only: When true, applies mappings only to the
@@ -403,12 +358,9 @@ class IndicesClient(NamespacedClient):
         if body in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'body'.")
 
-        if doc_type not in SKIP_IN_PATH and index in SKIP_IN_PATH:
-            index = "_all"
-
         return await self.transport.perform_request(
             "PUT",
-            _make_path(index, doc_type, "_mapping"),
+            _make_path(index, "_mapping"),
             params=params,
             headers=headers,
             body=body,
@@ -418,17 +370,15 @@ class IndicesClient(NamespacedClient):
         "allow_no_indices",
         "expand_wildcards",
         "ignore_unavailable",
-        "include_type_name",
         "local",
         "master_timeout",
     )
-    async def get_mapping(self, index=None, doc_type=None, params=None, headers=None):
+    async def get_mapping(self, index=None, params=None, headers=None):
         """
         Returns mappings for one or more indices.
 
 
         :arg index: A comma-separated list of index names
-        :arg doc_type: A comma-separated list of document types
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -437,15 +387,13 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg include_type_name: Whether to add the type name to the
-            response (default: false)
         :arg local: Return local information, do not retrieve the state
             from master node (default: false)
         :arg master_timeout: Specify timeout for connection to master
         """
         return await self.transport.perform_request(
             "GET",
-            _make_path(index, "_mapping", doc_type),
+            _make_path(index, "_mapping"),
             params=params,
             headers=headers,
         )
@@ -455,19 +403,15 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "include_defaults",
-        "include_type_name",
         "local",
     )
-    async def get_field_mapping(
-        self, fields, index=None, doc_type=None, params=None, headers=None
-    ):
+    async def get_field_mapping(self, fields, index=None, params=None, headers=None):
         """
         Returns mapping for one or more fields.
 
 
         :arg fields: A comma-separated list of fields
         :arg index: A comma-separated list of index names
-        :arg doc_type: A comma-separated list of document types
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -478,8 +422,6 @@ class IndicesClient(NamespacedClient):
             should be ignored when unavailable (missing or closed)
         :arg include_defaults: Whether the default mapping values should
             be returned as well
-        :arg include_type_name: Whether a type should be returned in the
-            body of the mappings.
         :arg local: Return local information, do not retrieve the state
             from master node (default: false)
         """
@@ -488,7 +430,7 @@ class IndicesClient(NamespacedClient):
 
         return await self.transport.perform_request(
             "GET",
-            _make_path(index, "_mapping", doc_type, "field", fields),
+            _make_path(index, "_mapping", "field", fields),
             params=params,
             headers=headers,
         )
@@ -609,7 +551,7 @@ class IndicesClient(NamespacedClient):
             "DELETE", _make_path(index, "_alias", name), params=params, headers=headers
         )
 
-    @query_params("create", "include_type_name", "master_timeout", "order")
+    @query_params("create", "master_timeout", "order")
     async def put_template(self, name, body, params=None, headers=None):
         """
         Creates or updates an index template.
@@ -619,8 +561,6 @@ class IndicesClient(NamespacedClient):
         :arg body: The template definition
         :arg create: Whether the index template should only be added if
             new or can also replace an existing one
-        :arg include_type_name: Whether a type should be returned in the
-            body of the mappings.
         :arg master_timeout: Specify timeout for connection to master
         :arg order: The order for this template when merging multiple
             matching ones (higher numbers are merged later, overriding the lower
@@ -659,7 +599,7 @@ class IndicesClient(NamespacedClient):
             "HEAD", _make_path("_template", name), params=params, headers=headers
         )
 
-    @query_params("flat_settings", "include_type_name", "local", "master_timeout")
+    @query_params("flat_settings", "local", "master_timeout")
     async def get_template(self, name=None, params=None, headers=None):
         """
         Returns an index template.
@@ -668,8 +608,6 @@ class IndicesClient(NamespacedClient):
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
             false)
-        :arg include_type_name: Whether a type should be returned in the
-            body of the mappings.
         :arg local: Return local information, do not retrieve the state
             from master node (default: false)
         :arg master_timeout: Explicit operation timeout for connection
@@ -867,9 +805,7 @@ class IndicesClient(NamespacedClient):
         "q",
         "rewrite",
     )
-    async def validate_query(
-        self, body=None, index=None, doc_type=None, params=None, headers=None
-    ):
+    async def validate_query(self, body=None, index=None, params=None, headers=None):
         """
         Allows a user to validate a potentially expensive query without executing it.
 
@@ -878,9 +814,6 @@ class IndicesClient(NamespacedClient):
         :arg index: A comma-separated list of index names to restrict
             the operation; use `_all` or empty string to perform the operation on
             all indices
-        :arg doc_type: A comma-separated list of document types to
-            restrict the operation; leave empty to perform the operation on all
-            types
         :arg all_shards: Execute validation on all shards instead of one
             random shard per index
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -907,7 +840,7 @@ class IndicesClient(NamespacedClient):
         """
         return await self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_validate", "query"),
+            _make_path(index, "_validate", "query"),
             params=params,
             headers=headers,
             body=body,
@@ -1016,31 +949,6 @@ class IndicesClient(NamespacedClient):
             "GET", _make_path(index, "_upgrade"), params=params, headers=headers
         )
 
-    @query_params("allow_no_indices", "expand_wildcards", "ignore_unavailable")
-    async def flush_synced(self, index=None, params=None, headers=None):
-        """
-        Performs a synced flush operation on one or more indices. Synced flush is
-        deprecated. Use flush instead
-
-
-        :arg index: A comma-separated list of index names; use `_all` or
-            empty string for all indices
-        :arg allow_no_indices: Whether to ignore if a wildcard indices
-            expression resolves into no concrete indices. (This includes `_all`
-            string or when no indices have been specified)
-        :arg expand_wildcards: Whether to expand wildcard expression to
-            concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
-        :arg ignore_unavailable: Whether specified concrete indices
-            should be ignored when unavailable (missing or closed)
-        """
-        return await self.transport.perform_request(
-            "POST",
-            _make_path(index, "_flush", "synced"),
-            params=params,
-            headers=headers,
-        )
-
     @query_params(
         "allow_no_indices", "expand_wildcards", "ignore_unavailable", "status"
     )
@@ -1166,7 +1074,6 @@ class IndicesClient(NamespacedClient):
 
     @query_params(
         "dry_run",
-        "include_type_name",
         "master_timeout",
         "timeout",
         "wait_for_active_shards",
@@ -1186,8 +1093,6 @@ class IndicesClient(NamespacedClient):
         :arg dry_run: If set to true the rollover action will only be
             validated but not actually performed even if a condition matches. The
             default is false
-        :arg include_type_name: Whether a type should be included in the
-            body of the mappings.
         :arg master_timeout: Specify timeout for connection to master
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
