@@ -257,7 +257,7 @@ class OpenSearch(object):
         "version_type",
         "wait_for_active_shards",
     )
-    def create(self, index, id, body, doc_type=None, params=None, headers=None):
+    def create(self, index, id, body, params=None, headers=None):
         """
         Creates a new document in the index.  Returns a 409 response when a document
         with a same ID already exists in the index.
@@ -266,7 +266,6 @@ class OpenSearch(object):
         :arg index: The name of the index
         :arg id: Document ID
         :arg body: The document
-        :arg doc_type: The type of the document
         :arg pipeline: The pipeline id to preprocess incoming documents
             with
         :arg refresh: If `true` then refresh the affected shards to make
@@ -288,10 +287,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_create", id)
-        else:
-            path = _make_path(index, doc_type, id, "_create")
+        path = _make_path(index, "_create", id)
 
         return self.transport.perform_request(
             "PUT", path, params=params, headers=headers, body=body
@@ -310,14 +306,13 @@ class OpenSearch(object):
         "version_type",
         "wait_for_active_shards",
     )
-    def index(self, index, body, doc_type=None, id=None, params=None, headers=None):
+    def index(self, index, body, id=None, params=None, headers=None):
         """
         Creates or updates a document in an index.
 
 
         :arg index: The name of the index
         :arg body: The document
-        :arg doc_type: The type of the document
         :arg id: Document ID
         :arg if_primary_term: only perform the index operation if the
             last operation that has changed the document has the specified primary
@@ -351,8 +346,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type is None:
-            doc_type = "_doc"
+        doc_type = "_doc"
 
         return self.transport.perform_request(
             "POST" if id in SKIP_IN_PATH else "PUT",
@@ -373,7 +367,7 @@ class OpenSearch(object):
         "timeout",
         "wait_for_active_shards",
     )
-    def bulk(self, body, index=None, doc_type=None, params=None, headers=None):
+    def bulk(self, body, index=None, params=None, headers=None):
         """
         Allows to perform multiple index/update/delete operations in a single request.
 
@@ -381,8 +375,6 @@ class OpenSearch(object):
         :arg body: The operation definition and data (action-data
             pairs), separated by newlines
         :arg index: Default index for items which don't provide one
-        :arg doc_type: Default document type for items which don't
-            provide one
         :arg _source: True or false to return the _source field or not,
             or default list of fields to return, can be overridden on each sub-
             request
@@ -412,7 +404,7 @@ class OpenSearch(object):
         body = _bulk_body(self.transport.serializer, body)
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_bulk"),
+            _make_path(index, "_bulk"),
             params=params,
             headers=headers,
             body=body,
@@ -455,7 +447,7 @@ class OpenSearch(object):
         "routing",
         "terminate_after",
     )
-    def count(self, body=None, index=None, doc_type=None, params=None, headers=None):
+    def count(self, body=None, index=None, params=None, headers=None):
         """
         Returns number of documents matching a query.
 
@@ -464,8 +456,6 @@ class OpenSearch(object):
             Query DSL (optional)
         :arg index: A comma-separated list of indices to restrict the
             results
-        :arg doc_type: A comma-separated list of types to restrict the
-            results
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -496,7 +486,7 @@ class OpenSearch(object):
         """
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_count"),
+            _make_path(index, "_count"),
             params=params,
             headers=headers,
             body=body,
@@ -512,14 +502,13 @@ class OpenSearch(object):
         "version_type",
         "wait_for_active_shards",
     )
-    def delete(self, index, id, doc_type=None, params=None, headers=None):
+    def delete(self, index, id, params=None, headers=None):
         """
         Removes a document from the index.
 
 
         :arg index: The name of the index
         :arg id: The document ID
-        :arg doc_type: The type of the document
         :arg if_primary_term: only perform the delete operation if the
             last operation that has changed the document has the specified primary
             term
@@ -545,8 +534,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            doc_type = "_doc"
+        doc_type = "_doc"
 
         return self.transport.perform_request(
             "DELETE", _make_path(index, doc_type, id), params=params, headers=headers
@@ -587,7 +575,7 @@ class OpenSearch(object):
         "wait_for_active_shards",
         "wait_for_completion",
     )
-    def delete_by_query(self, index, body, doc_type=None, params=None, headers=None):
+    def delete_by_query(self, index, body, params=None, headers=None):
         """
         Deletes documents matching the provided query.
 
@@ -595,8 +583,6 @@ class OpenSearch(object):
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
         :arg body: The search definition using the Query DSL
-        :arg doc_type: A comma-separated list of document types to
-            search; leave empty to perform the operation on all types
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -675,7 +661,7 @@ class OpenSearch(object):
 
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_delete_by_query"),
+            _make_path(index, "_delete_by_query"),
             params=params,
             headers=headers,
             body=body,
@@ -731,15 +717,13 @@ class OpenSearch(object):
         "version",
         "version_type",
     )
-    def exists(self, index, id, doc_type=None, params=None, headers=None):
+    def exists(self, index, id, params=None, headers=None):
         """
         Returns information about whether a document exists in an index.
 
 
         :arg index: The name of the index
         :arg id: The document ID
-        :arg doc_type: The type of the document (use `_all` to fetch the
-            first document matching the ID across all types)
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -763,8 +747,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            doc_type = "_doc"
+        doc_type = "_doc"
 
         return self.transport.perform_request(
             "HEAD", _make_path(index, doc_type, id), params=params, headers=headers
@@ -781,15 +764,13 @@ class OpenSearch(object):
         "version",
         "version_type",
     )
-    def exists_source(self, index, id, doc_type=None, params=None, headers=None):
+    def exists_source(self, index, id, params=None, headers=None):
         """
         Returns information about whether a document source exists in an index.
 
 
         :arg index: The name of the index
         :arg id: The document ID
-        :arg doc_type: The type of the document; deprecated and optional
-            starting with 7.0
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -811,10 +792,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_source", id)
-        else:
-            path = _make_path(index, doc_type, id, "_source")
+        path = _make_path(index, "_source", id)
 
         return self.transport.perform_request(
             "HEAD", path, params=params, headers=headers
@@ -834,7 +812,7 @@ class OpenSearch(object):
         "routing",
         "stored_fields",
     )
-    def explain(self, index, id, body=None, doc_type=None, params=None, headers=None):
+    def explain(self, index, id, body=None, params=None, headers=None):
         """
         Returns information about why a specific matches (or doesn't match) a query.
 
@@ -842,7 +820,6 @@ class OpenSearch(object):
         :arg index: The name of the index
         :arg id: The document ID
         :arg body: The query definition using the Query DSL
-        :arg doc_type: The type of the document
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -869,10 +846,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_explain", id)
-        else:
-            path = _make_path(index, doc_type, id, "_explain")
+        path = _make_path(index, "_explain", id)
 
         return self.transport.perform_request(
             "POST", path, params=params, headers=headers, body=body
@@ -926,15 +900,13 @@ class OpenSearch(object):
         "version",
         "version_type",
     )
-    def get(self, index, id, doc_type=None, params=None, headers=None):
+    def get(self, index, id, params=None, headers=None):
         """
         Returns a document.
 
 
         :arg index: The name of the index
         :arg id: The document ID
-        :arg doc_type: The type of the document (use `_all` to fetch the
-            first document matching the ID across all types)
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -958,8 +930,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            doc_type = "_doc"
+        doc_type = "_doc"
 
         return self.transport.perform_request(
             "GET", _make_path(index, doc_type, id), params=params, headers=headers
@@ -992,15 +963,13 @@ class OpenSearch(object):
         "version",
         "version_type",
     )
-    def get_source(self, index, id, doc_type=None, params=None, headers=None):
+    def get_source(self, index, id, params=None, headers=None):
         """
         Returns the source of a document.
 
 
         :arg index: The name of the index
         :arg id: The document ID
-        :arg doc_type: The type of the document; deprecated and optional
-            starting with 7.0
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -1022,10 +991,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_source", id)
-        else:
-            path = _make_path(index, doc_type, id, "_source")
+        path = _make_path(index, "_source", id)
 
         return self.transport.perform_request(
             "GET", path, params=params, headers=headers
@@ -1041,7 +1007,7 @@ class OpenSearch(object):
         "routing",
         "stored_fields",
     )
-    def mget(self, body, index=None, doc_type=None, params=None, headers=None):
+    def mget(self, body, index=None, params=None, headers=None):
         """
         Allows to get multiple documents in one request.
 
@@ -1050,7 +1016,6 @@ class OpenSearch(object):
             (containing full document information) or `ids` (when index and type is
             provided in the URL.
         :arg index: The name of the index
-        :arg doc_type: The type of the document
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -1072,7 +1037,7 @@ class OpenSearch(object):
 
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_mget"),
+            _make_path(index, "_mget"),
             params=params,
             headers=headers,
             body=body,
@@ -1087,7 +1052,7 @@ class OpenSearch(object):
         "search_type",
         "typed_keys",
     )
-    def msearch(self, body, index=None, doc_type=None, params=None, headers=None):
+    def msearch(self, body, index=None, params=None, headers=None):
         """
         Allows to execute several search operations in one request.
 
@@ -1096,8 +1061,6 @@ class OpenSearch(object):
             definition pairs), separated by newlines
         :arg index: A comma-separated list of index names to use as
             default
-        :arg doc_type: A comma-separated list of document types to use
-            as default
         :arg ccs_minimize_roundtrips: Indicates whether network round-
             trips should be minimized as part of cross-cluster search requests
             execution  Default: true
@@ -1127,7 +1090,7 @@ class OpenSearch(object):
         body = _bulk_body(self.transport.serializer, body)
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_msearch"),
+            _make_path(index, "_msearch"),
             params=params,
             headers=headers,
             body=body,
@@ -1140,9 +1103,7 @@ class OpenSearch(object):
         "search_type",
         "typed_keys",
     )
-    def msearch_template(
-        self, body, index=None, doc_type=None, params=None, headers=None
-    ):
+    def msearch_template(self, body, index=None, params=None, headers=None):
         """
         Allows to execute several search template operations in one request.
 
@@ -1151,8 +1112,6 @@ class OpenSearch(object):
             definition pairs), separated by newlines
         :arg index: A comma-separated list of index names to use as
             default
-        :arg doc_type: A comma-separated list of document types to use
-            as default
         :arg ccs_minimize_roundtrips: Indicates whether network round-
             trips should be minimized as part of cross-cluster search requests
             execution  Default: true
@@ -1171,7 +1130,7 @@ class OpenSearch(object):
         body = _bulk_body(self.transport.serializer, body)
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_msearch", "template"),
+            _make_path(index, "_msearch", "template"),
             params=params,
             headers=headers,
             body=body,
@@ -1191,9 +1150,7 @@ class OpenSearch(object):
         "version",
         "version_type",
     )
-    def mtermvectors(
-        self, body=None, index=None, doc_type=None, params=None, headers=None
-    ):
+    def mtermvectors(self, body=None, index=None, params=None, headers=None):
         """
         Returns multiple termvectors in one request.
 
@@ -1202,7 +1159,6 @@ class OpenSearch(object):
             parameters per document here. You must at least provide a list of
             document ids. See documentation.
         :arg index: The index in which the document resides.
-        :arg doc_type: The type of the document.
         :arg field_statistics: Specifies if document count, sum of
             document frequencies and sum of total term frequencies should be
             returned. Applies to all returned documents unless otherwise specified
@@ -1235,10 +1191,7 @@ class OpenSearch(object):
         :arg version_type: Specific version type  Valid choices:
             internal, external, external_gte, force
         """
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_mtermvectors")
-        else:
-            path = _make_path(index, doc_type, "_mtermvectors")
+        path = _make_path(index, "_mtermvectors")
 
         return self.transport.perform_request(
             "POST", path, params=params, headers=headers, body=body
@@ -1482,7 +1435,7 @@ class OpenSearch(object):
         "typed_keys",
         "version",
     )
-    def search(self, body=None, index=None, doc_type=None, params=None, headers=None):
+    def search(self, body=None, index=None, params=None, headers=None):
         """
         Returns results matching a query.
 
@@ -1490,8 +1443,6 @@ class OpenSearch(object):
         :arg body: The search definition using the Query DSL
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
-        :arg doc_type: A comma-separated list of document types to
-            search; leave empty to perform the operation on all types
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -1592,7 +1543,7 @@ class OpenSearch(object):
 
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_search"),
+            _make_path(index, "_search"),
             params=params,
             headers=headers,
             body=body,
@@ -1647,9 +1598,7 @@ class OpenSearch(object):
         "search_type",
         "typed_keys",
     )
-    def search_template(
-        self, body, index=None, doc_type=None, params=None, headers=None
-    ):
+    def search_template(self, body, index=None, params=None, headers=None):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
@@ -1657,8 +1606,6 @@ class OpenSearch(object):
         :arg body: The search definition template and its params
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
-        :arg doc_type: A comma-separated list of document types to
-            search; leave empty to perform the operation on all types
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -1692,7 +1639,7 @@ class OpenSearch(object):
 
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_search", "template"),
+            _make_path(index, "_search", "template"),
             params=params,
             headers=headers,
             body=body,
@@ -1711,9 +1658,7 @@ class OpenSearch(object):
         "version",
         "version_type",
     )
-    def termvectors(
-        self, index, body=None, doc_type=None, id=None, params=None, headers=None
-    ):
+    def termvectors(self, index, body=None, id=None, params=None, headers=None):
         """
         Returns information and statistics about terms in the fields of a particular
         document.
@@ -1722,7 +1667,6 @@ class OpenSearch(object):
         :arg index: The index in which the document resides.
         :arg body: Define parameters and or supply a document to get
             termvectors for. See documentation.
-        :arg doc_type: The type of the document.
         :arg id: The id of the document, when not specified a doc param
             should be supplied.
         :arg field_statistics: Specifies if document count, sum of
@@ -1749,10 +1693,7 @@ class OpenSearch(object):
         if index in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'index'.")
 
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_termvectors", id)
-        else:
-            path = _make_path(index, doc_type, id, "_termvectors")
+        path = _make_path(index, "_termvectors", id)
 
         return self.transport.perform_request(
             "POST", path, params=params, headers=headers, body=body
@@ -1772,7 +1713,7 @@ class OpenSearch(object):
         "timeout",
         "wait_for_active_shards",
     )
-    def update(self, index, id, body, doc_type=None, params=None, headers=None):
+    def update(self, index, id, body, params=None, headers=None):
         """
         Updates a document with a script or partial document.
 
@@ -1781,7 +1722,6 @@ class OpenSearch(object):
         :arg id: Document ID
         :arg body: The request definition requires either `script` or
             partial `doc`
-        :arg doc_type: The type of the document
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
         :arg _source_excludes: A list of fields to exclude from the
@@ -1815,10 +1755,7 @@ class OpenSearch(object):
             if param in SKIP_IN_PATH:
                 raise ValueError("Empty value passed for a required argument.")
 
-        if doc_type in SKIP_IN_PATH:
-            path = _make_path(index, "_update", id)
-        else:
-            path = _make_path(index, doc_type, id, "_update")
+        path = _make_path(index, "_update", id)
 
         return self.transport.perform_request(
             "POST", path, params=params, headers=headers, body=body
@@ -1861,9 +1798,7 @@ class OpenSearch(object):
         "wait_for_active_shards",
         "wait_for_completion",
     )
-    def update_by_query(
-        self, index, body=None, doc_type=None, params=None, headers=None
-    ):
+    def update_by_query(self, index, body=None, params=None, headers=None):
         """
         Performs an update on every document in the index without changing the source,
         for example to pick up a mapping change.
@@ -1872,7 +1807,6 @@ class OpenSearch(object):
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
         :arg body: The search definition using the Query DSL
-        :arg doc_type: A comma-separated list of document types to
             search; leave empty to perform the operation on all types
         :arg _source: True or false to return the _source field or not,
             or a list of fields to return
@@ -1955,7 +1889,7 @@ class OpenSearch(object):
 
         return self.transport.perform_request(
             "POST",
-            _make_path(index, doc_type, "_update_by_query"),
+            _make_path(index, "_update_by_query"),
             params=params,
             headers=headers,
             body=body,
